@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -92,14 +92,14 @@ class GeneralTab(SettingsTab):
         self.monitorLayout.addWidget(self.customWidthLabel, 3, 3)
         self.customWidthValueEdit = QtGui.QSpinBox(self.monitorGroupBox)
         self.customWidthValueEdit.setObjectName(u'customWidthValueEdit')
-        self.customWidthValueEdit.setMaximum(9999)
+        self.customWidthValueEdit.setRange(1, 9999)
         self.monitorLayout.addWidget(self.customWidthValueEdit, 4, 3)
         self.customHeightLabel = QtGui.QLabel(self.monitorGroupBox)
         self.customHeightLabel.setObjectName(u'customHeightLabel')
         self.monitorLayout.addWidget(self.customHeightLabel, 3, 4)
         self.customHeightValueEdit = QtGui.QSpinBox(self.monitorGroupBox)
         self.customHeightValueEdit.setObjectName(u'customHeightValueEdit')
-        self.customHeightValueEdit.setMaximum(9999)
+        self.customHeightValueEdit.setRange(1, 9999)
         self.monitorLayout.addWidget(self.customHeightValueEdit, 4, 4)
         self.displayOnMonitorCheck = QtGui.QCheckBox(self.monitorGroupBox)
         self.displayOnMonitorCheck.setObjectName(u'monitorComboBox')
