@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -175,8 +175,10 @@ class MainDisplay(Display):
     def setTransparency(self, enabled):
         if enabled:
             self.setAutoFillBackground(False)
+            self.setStyleSheet("QGraphicsView {background: transparent; border: 0px;}")
         else:
             self.setAttribute(QtCore.Qt.WA_NoSystemBackground, False)
+            self.setStyleSheet("QGraphicsView {}")
         self.setAttribute(QtCore.Qt.WA_TranslucentBackground, enabled)
         self.repaint()
 
@@ -362,6 +364,7 @@ class MainDisplay(Display):
         Generates a preview of the image displayed.
         """
         log.debug(u'preview for %s', self.isLive)
+        was_visible = self.isVisible()
         Receiver.send_message(u'openlp_process_events')
         # We must have a service item to preview.
         if self.isLive and hasattr(self, u'serviceItem'):
@@ -380,7 +383,8 @@ class MainDisplay(Display):
         if self.isLive:
             if self.hideMode:
                 self.hideDisplay(self.hideMode)
-            else:
+            # Only continue if the visibility wasn't changed during method call.
+            elif was_visible == self.isVisible():
                 # Single screen active
                 if self.screens.display_count == 1:
                     # Only make visible if setting enabled.
