@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -82,13 +82,14 @@ PROGRESSBAR_STYLE = """
     }
 """
 
+
 class Ui_MainWindow(object):
     def setupUi(self, mainWindow):
         """
         Set up the user interface
         """
         mainWindow.setObjectName(u'MainWindow')
-        mainWindow.setWindowIcon(build_icon(u':/icon/openlp-logo-64x64.png'))
+        mainWindow.setWindowIcon(build_icon(u':/icon/openlp-logo.svg'))
         mainWindow.setDockNestingEnabled(True)
         # Set up the main container, which contains all the other form widgets.
         self.mainContent = QtGui.QWidget(mainWindow)
@@ -310,9 +311,9 @@ class Ui_MainWindow(object):
         # Give QT Extra Hint that this is the Preferences Menu Item
         self.settingsConfigureItem.setMenuRole(QtGui.QAction.PreferencesRole)
         self.settingsImportItem = create_action(mainWindow,
-           u'settingsImportItem', category=UiStrings().Settings)
+           u'settingsImportItem', category=UiStrings().Import)
         self.settingsExportItem = create_action(mainWindow,
-           u'settingsExportItem', category=UiStrings().Settings)
+           u'settingsExportItem', category=UiStrings().Export)
         action_list.add_category(unicode(UiStrings().Help),
             CategoryOrder.standardMenu)
         self.aboutItem = create_action(mainWindow, u'aboutItem',
