@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -423,10 +423,11 @@ class MediaController(object):
                     controller.volumeSlider.blockSignals(False)
                     return False
                 if status:
-                    display.frame.evaluateJavaScript(u'show_blank("desktop");')
+                    if not controller.media_info.is_background:
+                        display.frame.evaluateJavaScript(u'show_blank("desktop");')
                     self.curDisplayMediaPlayer[display].set_visible(display,
                         True)
-                    if controller.isLive:
+                    if controller.isLive and not controller.media_info.is_background:
                         if controller.hideMenu.defaultAction().isChecked():
                             controller.hideMenu.defaultAction().trigger()
         # Start Timer for ui updates
