@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -229,32 +229,32 @@ FLASH_HTML = u"""
 """
 
 VIDEO_EXT = [
-        u'*.3gp'
-        , u'*.3gpp'
-        , u'*.3g2'
-        , u'*.3gpp2'
-        , u'*.aac'
-        , u'*.flv'
-        , u'*.f4a'
-        , u'*.f4b'
-        , u'*.f4p'
-        , u'*.f4v'
-        , u'*.mov'
-        , u'*.m4a'
-        , u'*.m4b'
-        , u'*.m4p'
-        , u'*.m4v'
-        , u'*.mkv'
-        , u'*.mp4'
-        , u'*.ogv'
-        , u'*.webm'
-        , u'*.mpg', u'*.wmv',  u'*.mpeg', u'*.avi'
-        , u'*.swf'
+        u'*.3gp',
+        u'*.3gpp',
+        u'*.3g2',
+        u'*.3gpp2',
+        u'*.aac',
+        u'*.flv',
+        u'*.f4a',
+        u'*.f4b',
+        u'*.f4p',
+        u'*.f4v',
+        u'*.mov',
+        u'*.m4a',
+        u'*.m4b',
+        u'*.m4p',
+        u'*.m4v',
+        u'*.mkv',
+        u'*.mp4',
+        u'*.ogv',
+        u'*.webm',
+        u'*.mpg', u'*.wmv',  u'*.mpeg', u'*.avi',
+        u'*.swf'
     ]
 
 AUDIO_EXT = [
-        u'*.mp3'
-        , u'*.ogg'
+        u'*.mp3',
+        u'*.ogg'
     ]
 
 
