@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -44,6 +44,7 @@ from openlp.core.utils.actions import ActionList, CategoryOrder
 
 log = logging.getLogger(__name__)
 
+
 class SlideList(QtGui.QTableWidget):
     """
     Customised version of QTableWidget which can respond to keyboard
@@ -101,7 +102,6 @@ class SlideController(Controller):
             u'delaySpinBox'
         ]
         self.audioList = [
-            u'songMenu',
             u'audioPauseItem',
             u'audioTimeLabel'
         ]
@@ -287,7 +287,7 @@ class SlideController(Controller):
                 text=translate('OpenLP.SlideController', 'Pause Audio'),
                 tooltip=translate('OpenLP.SlideController', 'Pause audio.'),
                 checked=False, visible=False, category=self.category,
-                context=QtCore.Qt.WindowShortcut, 
+                context=QtCore.Qt.WindowShortcut,
                 shortcuts=[], triggers=self.onAudioPauseClicked)
             self.audioMenu = QtGui.QMenu(
                 translate('OpenLP.SlideController', 'Background Audio'), self.toolbar)
@@ -319,6 +319,7 @@ class SlideController(Controller):
             self.audioTimeLabel.setObjectName(u'audioTimeLabel')
             self.toolbar.addToolbarWidget(self.audioTimeLabel)
             self.toolbar.setWidgetVisible(self.audioList, False)
+            self.toolbar.setWidgetVisible([u'songMenu'], False)
         # Screen preview area
         self.previewFrame = QtGui.QFrame(self.splitter)
         self.previewFrame.setGeometry(QtCore.QRect(0, 0, 300, 300 * self.ratio))
@@ -391,6 +392,8 @@ class SlideController(Controller):
         # Signals
         QtCore.QObject.connect(self.previewListWidget,
             QtCore.SIGNAL(u'clicked(QModelIndex)'), self.onSlideSelected)
+        QtCore.QObject.connect(self.previewListWidget.verticalHeader(),
+            QtCore.SIGNAL(u'sectionClicked(int)'), self.onSlideSelected)
         if self.isLive:
             QtCore.QObject.connect(Receiver.get_receiver(),
                 QtCore.SIGNAL(u'slidecontroller_live_spin_delay'),
@@ -525,6 +528,7 @@ class SlideController(Controller):
     def liveEscape(self):
         self.display.setVisible(False)
         self.mediaController.video_stop([self])
+        self.onPlaySlidesLoop(False)
 
     def toggleDisplay(self, action):
         """
@@ -689,6 +693,7 @@ class SlideController(Controller):
         self.toolbar.hide()
         self.mediabar.hide()
         self.songMenu.hide()
+        self.toolbar.setWidgetVisible([u'songMenu'], False)
         self.toolbar.setWidgetVisible(self.loopList, False)
         # Reset the button
         self.playSlidesOnce.setChecked(False)
@@ -699,7 +704,7 @@ class SlideController(Controller):
             if Settings().value(
                 self.parent().songsSettingsSection + u'/display songbar',
                 QtCore.QVariant(True)).toBool() and self.slideList:
-                self.songMenu.show()
+                self.toolbar.setWidgetVisible([u'songMenu'], True)
         if item.is_capable(ItemCapabilities.CanLoop) and \
             len(item.get_frames()) > 1:
             self.toolbar.setWidgetVisible(self.loopList)
@@ -1080,7 +1085,7 @@ class SlideController(Controller):
             else:
                 Receiver.send_message(u'live_display_show')
 
-    def onSlideSelected(self):
+    def onSlideSelected(self, index):
         """
         Slide selected in controller
         """
