@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -29,14 +29,14 @@
 
 from PyQt4 import QtGui
 
-from openlp.core.lib import translate
+from openlp.core.lib import translate, build_icon
 from openlp.core.lib.ui import create_button_box
 
 
 class Ui_ThemeLayoutDialog(object):
     def setupUi(self, themeLayoutDialog):
         themeLayoutDialog.setObjectName(u'themeLayoutDialogDialog')
-        #themeLayoutDialog.resize(300, 200)
+        themeLayoutDialog.setWindowIcon(build_icon(u':/icon/openlp-logo.svg'))
         self.previewLayout = QtGui.QVBoxLayout(themeLayoutDialog)
         self.previewLayout.setObjectName(u'previewLayout')
         self.previewArea = QtGui.QWidget(themeLayoutDialog)
