@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -36,7 +36,7 @@ class Ui_AlertDialog(object):
     def setupUi(self, alertDialog):
         alertDialog.setObjectName(u'alertDialog')
         alertDialog.resize(400, 300)
-        alertDialog.setWindowIcon(build_icon(u':/icon/openlp-logo-16x16.png'))
+        alertDialog.setWindowIcon(build_icon(u':/icon/openlp-logo.svg'))
         self.alertDialogLayout = QtGui.QGridLayout(alertDialog)
         self.alertDialogLayout.setObjectName(u'alertDialogLayout')
         self.alertTextLayout = QtGui.QFormLayout()
