@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -39,8 +39,7 @@ class Ui_EditBibleDialog(object):
     def setupUi(self, editBibleDialog):
         editBibleDialog.setObjectName(u'editBibleDialog')
         editBibleDialog.resize(520, 400)
-        editBibleDialog.setWindowIcon(
-            build_icon(u':/icon/openlp-logo-16x16.png'))
+        editBibleDialog.setWindowIcon(build_icon(u':/icon/openlp-logo.svg'))
         editBibleDialog.setModal(True)
         self.dialogLayout = QtGui.QVBoxLayout(editBibleDialog)
         self.dialogLayout.setSpacing(8)
@@ -128,7 +127,7 @@ class Ui_EditBibleDialog(object):
             self.bookNameEdit[book[u'abbreviation']].setObjectName(
                 u'bookNameEdit[%s]' % book[u'abbreviation'])
             self.bookNameWidgetLayout.addRow(
-                self.bookNameLabel[book[u'abbreviation']], 
+                self.bookNameLabel[book[u'abbreviation']],
                 self.bookNameEdit[book[u'abbreviation']])
         self.scrollArea.setWidget(self.bookNameWidget)
         self.bookNameTabLayout.addWidget(self.scrollArea)
