@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -39,6 +39,7 @@ from openlp.plugins.bibles.lib import LayoutStyle, DisplayStyle, \
 
 log = logging.getLogger(__name__)
 
+
 class BiblesTab(SettingsTab):
     """
     BiblesTab is the Bibles settings tab in the settings dialog.
@@ -293,7 +294,7 @@ class BiblesTab(SettingsTab):
             translate('BiblesPlugin.BiblesTab', 'English'))
 
     def onBibleThemeComboBoxChanged(self):
-        self.bible_theme = self.bibleThemeComboBox.currentText()
+        self.bible_theme = unicode(self.bibleThemeComboBox.currentText())
 
     def onDisplayStyleComboBoxChanged(self):
         self.display_style = self.displayStyleComboBox.currentIndex()
