@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -32,9 +32,11 @@ import logging
 import os
 import re
 import sqlite3
+import time
 
 from PyQt4 import QtCore
 from sqlalchemy import Column, ForeignKey, or_, Table, types, func
+from sqlalchemy.exc import OperationalError
 from sqlalchemy.orm import class_mapper, mapper, relation
 from sqlalchemy.orm.exc import UnmappedClassError
 
@@ -48,6 +50,7 @@ log = logging.getLogger(__name__)
 
 RESERVED_CHARACTERS = u'\\.^$*+?{}[]()'
 
+
 class BibleMeta(BaseModel):
     """
     Bible Meta Data
@@ -257,7 +260,12 @@ class BibleDB(QtCore.QObject, Manager):
                 text=verse_text
             )
             self.session.add(verse)
-        self.session.commit()
+        try:
+            self.session.commit()
+        except OperationalError:
+            # Wait 10ms and try again.
+            time.sleep(0.01)
+            self.session.commit()
 
     def create_verse(self, book_id, chapter, verse, text):
         """
@@ -363,7 +371,7 @@ class BibleDB(QtCore.QObject, Manager):
 
         ``book``
             The name of the book, according to the selected language.
-        
+
         ``language_selection``
             The language selection the user has chosen in the settings
             section of the Bible.
@@ -862,6 +870,26 @@ class BiblesResourcesDB(QtCore.QObject, Manager):
                 return book[0]
         return None
 
+    @staticmethod
+    def get_language_by_id(language_id):
+        """
+        Return a dict containing the language id, name and code by id.
+
+        ``id``
+            The id of the language in the database.
+        """
+        log.debug(u'BiblesResourcesDB.get_language_by_id(%d)', language_id)
+        language = BiblesResourcesDB.run_sql(u'SELECT id, name, code FROM '
+                u'language WHERE id = ?', (language_id,))
+        if language:
+            return {
+                u'id': language[0][0],
+                u'name': unicode(language[0][1]),
+                u'code': unicode(language[0][2])
+            }
+        else:
+            return None
+
     @staticmethod
     def get_language(name):
         """
@@ -1041,7 +1069,7 @@ class OldBibleDB(QtCore.QObject, Manager):
         QtCore.QObject.__init__(self)
         if u'path' not in kwargs:
             raise KeyError(u'Missing keyword argument "path".')
-        if  u'file' not in kwargs:
+        if u'file' not in kwargs:
             raise KeyError(u'Missing keyword argument "file".')
         if u'path' in kwargs:
             self.path = kwargs[u'path']
