@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -47,6 +47,7 @@ from openlp.plugins.bibles.lib.db import BiblesResourcesDB
 
 log = logging.getLogger(__name__)
 
+
 class BibleSearch(object):
     """
     Enumeration class for the different search methods for the "quick search".
@@ -62,7 +63,6 @@ class BibleMediaItem(MediaManagerItem):
     log.info(u'Bible Media Item loaded')
 
     def __init__(self, parent, plugin, icon):
-        self.IconPath = u'songs/song'
         self.lockIcon = build_icon(u':/bibles/bibles_search_lock.png')
         self.unlockIcon = build_icon(u':/bibles/bibles_search_unlock.png')
         MediaManagerItem.__init__(self, parent, plugin, icon)
@@ -180,6 +180,8 @@ class BibleMediaItem(MediaManagerItem):
         tab.setVisible(False)
         QtCore.QObject.connect(lockButton, QtCore.SIGNAL(u'toggled(bool)'),
             self.onLockButtonToggled)
+        QtCore.QObject.connect(secondComboBox, QtCore.SIGNAL(u'currentIndexChanged(QString)'),
+                               self.onSecondBibleComboBoxCurrentIndexChanged)
         setattr(self, prefix + u'VersionLabel', versionLabel)
         setattr(self, prefix + u'VersionComboBox', versionComboBox)
         setattr(self, prefix + u'SecondLabel', secondLabel)
@@ -299,15 +301,15 @@ class BibleMediaItem(MediaManagerItem):
         log.debug(u'configUpdated')
         if Settings().value(self.settingsSection + u'/second bibles',
             QtCore.QVariant(True)).toBool():
-            self.advancedSecondLabel.setVisible(True)
-            self.advancedSecondComboBox.setVisible(True)
             self.quickSecondLabel.setVisible(True)
             self.quickSecondComboBox.setVisible(True)
+            self.advancedSecondLabel.setVisible(True)
+            self.advancedSecondComboBox.setVisible(True)
         else:
-            self.advancedSecondLabel.setVisible(False)
-            self.advancedSecondComboBox.setVisible(False)
             self.quickSecondLabel.setVisible(False)
             self.quickSecondComboBox.setVisible(False)
+            self.advancedSecondLabel.setVisible(False)
+            self.advancedSecondComboBox.setVisible(False)
         self.quickStyleComboBox.setCurrentIndex(self.settings.layout_style)
         self.advancedStyleComboBox.setCurrentIndex(self.settings.layout_style)
 
@@ -542,6 +544,14 @@ class BibleMediaItem(MediaManagerItem):
                 books.sort(cmp=locale_compare)
         set_case_insensitive_completer(books, self.quickSearchEdit)
 
+    def onSecondBibleComboBoxCurrentIndexChanged(self, text):
+        if text is None or not unicode(text):
+            self.quickStyleComboBox.setEnabled(True)
+            self.advancedStyleComboBox.setEnabled(True)
+        else:
+            self.quickStyleComboBox.setEnabled(False)
+            self.advancedStyleComboBox.setEnabled(False)
+
     def onImportClick(self):
         if not hasattr(self, u'import_wizard'):
             self.import_wizard = BibleImportForm(self, self.plugin.manager,
