@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -44,6 +44,7 @@ import time
 if os.name == u'nt':
     from win32com.client import Dispatch
     import pywintypes
+
     # Declare an empty exception to match the exception imported from UNO
     class ErrorCodeIOException(Exception):
         pass
@@ -63,6 +64,7 @@ from presentationcontroller import PresentationController, PresentationDocument
 
 log = logging.getLogger(__name__)
 
+
 class ImpressController(PresentationController):
     """
     Class to control interactions with Impress presentations.
@@ -79,7 +81,7 @@ class ImpressController(PresentationController):
         PresentationController.__init__(self, plugin, u'Impress',
             ImpressDocument)
         self.supports = [u'odp']
-        self.alsosupports = [u'ppt', u'pps', u'pptx', u'ppsx']
+        self.alsosupports = [u'ppt', u'pps', u'pptx', u'ppsx', u'pptm']
         self.process = None
         self.desktop = None
         self.manager = None
