@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -45,6 +45,7 @@ log = logging.getLogger(__name__)
 
 ERROR = QtGui.QImage(u':/general/general_delete.png')
 
+
 class PresentationMediaItem(MediaManagerItem):
     """
     This is the Presentation media manager item for Presentation Items.
@@ -88,10 +89,10 @@ class PresentationMediaItem(MediaManagerItem):
             if self.controllers[controller].enabled():
                 types = self.controllers[controller].supports + \
                     self.controllers[controller].alsosupports
-                for type in types:
-                    if fileType.find(type) == -1:
-                        fileType += u'*.%s ' % type
-                        self.plugin.serviceManager.supportedSuffixes(type)
+                for type_ in types:
+                    if fileType.find(type_) == -1:
+                        fileType += u'*.%s ' % type_
+                        self.plugin.serviceManager.supportedSuffixes(type_)
         self.onNewFileMasks = unicode(translate('PresentationPlugin.MediaItem',
             'Presentations (%s)')) % fileType
 
@@ -152,7 +153,7 @@ class PresentationMediaItem(MediaManagerItem):
             if self.controllers[item].enabled():
                 self.displayTypeComboBox.addItem(item)
         if self.displayTypeComboBox.count() > 1:
-            self.displayTypeComboBox.insertItem(0, self.Automatic)
+            self.displayTypeComboBox.insertItem(0, self.Automatic, userData=u'automatic')
             self.displayTypeComboBox.setCurrentIndex(0)
         if Settings().value(self.settingsSection + u'/override app',
             QtCore.QVariant(QtCore.Qt.Unchecked)) == QtCore.Qt.Checked:
@@ -276,13 +277,13 @@ class PresentationMediaItem(MediaManagerItem):
         service_item.shortname = unicode(self.displayTypeComboBox.currentText())
         service_item.add_capability(ItemCapabilities.ProvidesOwnDisplay)
         service_item.add_capability(ItemCapabilities.HasDetailedTitleDisplay)
-        shortname = service_item.shortname
-        if not shortname:
+        if not service_item.shortname:
             return False
         for bitem in items:
             filename = unicode(bitem.data(QtCore.Qt.UserRole).toString())
             if os.path.exists(filename):
-                if shortname == self.Automatic:
+                if self.displayTypeComboBox.itemData(
+                    self.displayTypeComboBox.currentIndex()) == u'automatic':
                     service_item.shortname = self.findControllerByType(filename)
                     if not service_item.shortname:
                         return False
