@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -593,8 +593,11 @@ class HttpConnection(object):
         for header, value in response.headers.iteritems():
             http += '%s: %s\r\n' % (header, value)
         http += '\r\n'
-        self.socket.write(http)
-        self.socket.write(response.content)
+        if self.socket:
+            # Write to the socket if it's open, else ignore it.
+            # See http://support.openlp.org/scp/tickets.php?id=2112
+            self.socket.write(http)
+            self.socket.write(response.content)
 
     def disconnected(self):
         """
