@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -33,12 +33,12 @@ from openlp.core.lib import build_icon, translate
 from openlp.core.lib.ui import UiStrings, create_button_box, create_button
 from openlp.plugins.songs.lib.ui import SongStrings
 
+
 class Ui_EditSongDialog(object):
     def setupUi(self, editSongDialog):
         editSongDialog.setObjectName(u'editSongDialog')
         editSongDialog.resize(650, 400)
-        editSongDialog.setWindowIcon(
-            build_icon(u':/icon/openlp-logo-16x16.png'))
+        editSongDialog.setWindowIcon(build_icon(u':/icon/openlp-logo.svg'))
         editSongDialog.setModal(True)
         self.dialogLayout = QtGui.QVBoxLayout(editSongDialog)
         self.dialogLayout.setSpacing(8)
@@ -283,7 +283,6 @@ class Ui_EditSongDialog(object):
         self.bottomLayout.setObjectName(u'bottomLayout')
         self.warningLabel = QtGui.QLabel(editSongDialog)
         self.warningLabel.setObjectName(u'warningLabel')
-        self.warningLabel.setVisible(False)
         self.bottomLayout.addWidget(self.warningLabel)
         self.buttonBox = create_button_box(editSongDialog, u'buttonBox',
             [u'cancel', u'save'])
@@ -355,9 +354,10 @@ class Ui_EditSongDialog(object):
             translate('SongsPlugin.EditSongForm', '&Remove'))
         self.audioRemoveAllButton.setText(
             translate('SongsPlugin.EditSongForm', 'Remove &All'))
-        self.warningLabel.setText(
-            translate('SongsPlugin.EditSongForm', '<strong>Warning:</strong>'
-                ' Not all of the verses are in use.'))
+        self.notAlllVersesUsed = translate('SongsPlugin.EditSongForm', '<strong>Warning:</strong>'
+                ' Not all of the verses are in use.')
+        self.noVerseOrder = translate('SongsPlugin.EditSongForm', '<strong>Warning:</strong>'
+                ' You have not entered a verse order.')
 
 def editSongDialogComboBox(parent, name):
     """
