@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -34,7 +34,7 @@ import shutil
 
 from PyQt4 import QtCore, QtGui
 
-from openlp.core.lib import PluginStatus, Receiver, MediaType, translate, \
+from openlp.core.lib import FileDialog, PluginStatus, Receiver, MediaType, translate, \
     create_separated_list, check_directory_exists
 from openlp.core.lib.ui import UiStrings, set_case_insensitive_completer, \
     critical_error_message_box, find_and_set_in_combo_box
@@ -47,6 +47,7 @@ from editsongdialog import Ui_EditSongDialog
 
 log = logging.getLogger(__name__)
 
+
 class EditSongForm(QtGui.QDialog, Ui_EditSongDialog):
     """
     Class to manage the editing of a song
@@ -131,6 +132,27 @@ class EditSongForm(QtGui.QDialog, Ui_EditSongDialog):
         self.audioListWidget.setAlternatingRowColors(True)
         self.findVerseSplit = re.compile(u'---\[\]---\n', re.UNICODE)
         self.whitespace = re.compile(r'\W+', re.UNICODE)
+        self.find_tags = re.compile(u'\{/?\w+\}', re.UNICODE)
+
+    def keyPressEvent(self, event):
+        """
+        Reimplement the keyPressEvent to react on Return/Enter keys. When some
+        combo boxes have focus we do not want dialog's default action be
+        triggered but instead our own.
+
+        ``event``
+            A QtGui.QKeyEvent event.
+        """
+        if event.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return):
+            if self.authorsComboBox.hasFocus() and \
+                    self.authorsComboBox.currentText():
+                self.onAuthorAddButtonClicked()
+                return
+            if self.topicsComboBox.hasFocus() and \
+                    self.topicsComboBox.currentText():
+                self.onTopicAddButtonClicked()
+                return
+        QtGui.QDialog.keyPressEvent(self, event)
 
     def initialise(self):
         self.verseEditButton.setEnabled(False)
@@ -209,6 +231,7 @@ class EditSongForm(QtGui.QDialog, Ui_EditSongDialog):
         self.loadTopics()
         self.loadBooks()
         self.loadMediaFiles()
+        self.themeComboBox.setEditText(u'')
         self.themeComboBox.setCurrentIndex(0)
         # it's a new song to preview is not possible
         self.previewButton.setVisible(False)
@@ -241,6 +264,9 @@ class EditSongForm(QtGui.QDialog, Ui_EditSongDialog):
         if self.song.theme_name:
             find_and_set_in_combo_box(
                 self.themeComboBox, unicode(self.song.theme_name))
+        else:
+            self.themeComboBox.setEditText(u'')
+            self.themeComboBox.setCurrentIndex(0)
         self.copyrightEdit.setText(
             self.song.copyright if self.song.copyright else u'')
         self.commentsEdit.setPlainText(
@@ -329,6 +355,8 @@ class EditSongForm(QtGui.QDialog, Ui_EditSongDialog):
         self.titleEdit.setFocus(QtCore.Qt.OtherFocusReason)
         # Hide or show the preview button.
         self.previewButton.setVisible(preview)
+        # Check if all verse tags are used.
+        self.onVerseOrderTextChanged(self.verseOrderEdit.text())
 
     def tagRows(self):
         """
@@ -588,7 +616,12 @@ class EditSongForm(QtGui.QDialog, Ui_EditSongDialog):
         for verse in verses:
             if not verse in order:
                 verses_not_used.append(verse)
-        self.warningLabel.setVisible(len(verses_not_used) > 0)
+        label_text = u''
+        if not self.verseOrderEdit.text():
+            label_text = self.noVerseOrder
+        elif verses_not_used:
+            label_text = self.notAlllVersesUsed
+        self.warningLabel.setText(label_text)
 
     def __extractVerseOrder(self, verse_order):
         order = []
@@ -688,8 +721,53 @@ class EditSongForm(QtGui.QDialog, Ui_EditSongDialog):
                 self.manager.save_object(book)
             else:
                 return False
+        cnt_errors = 0
+        error_list = ''
+        verse_tag = []
+        verse_num = []
+        for i in range(self.verseListWidget.rowCount()):
+            item = self.verseListWidget.item(i, 0)
+            tags = self.find_tags.findall(item.text())
+            if self._validate_tags(tags) == False:
+                field = unicode(item.data(QtCore.Qt.UserRole).toString())
+                verse_tag.append(VerseType.translated_name(field[0]))
+                verse_num.append(field[1:])
+                cnt_errors += 1;
+        if cnt_errors > 0:
+            for i in range(cnt_errors):
+                error_list += '%s %s' % (verse_tag[i], verse_num[i])
+                if i < cnt_errors-1:
+                    error_list += ', '
+            critical_error_message_box(
+                message=translate('SongsPlugin.EditSongForm',
+                'There are misplaced formatting tags in the following verses:\n\n%s\n\n'
+                'Please correct these tags before continuing.' % error_list))
+            return False
         return True
 
+    def _validate_tags(self, _tags):
+        """
+        Validates a list of tags
+        Deletes the first affiliated tag pair which is located side by side in the list
+        and call itself recursively with the shortened tag list.
+        If there is any misplaced tag in the list, either the lenght of the tag list is not even,
+        or the function won't find any tag pairs side by side.
+        If there is no misplaced tag, the length of the list will be zero on any recursive run.
+
+        Return:
+            True if the function can't find any mismatched tags
+            False if there are mismatched tags.
+        """
+        if len(_tags) == 0:
+            return True
+        if len(_tags) % 2 != 0:
+            return False
+        for i in range(len(_tags)-1):
+            if _tags[i+1] == "{/" + _tags[i][1:]:
+                del _tags[i:i+2]
+                return self._validate_tags(_tags)
+        return False
+
     def onCopyrightInsertButtonTriggered(self):
         text = self.copyrightEdit.text()
         pos = self.copyrightEdit.cursorPosition()
@@ -730,7 +808,7 @@ class EditSongForm(QtGui.QDialog, Ui_EditSongDialog):
         Loads file(s) from the filesystem.
         """
         filters = u'%s (*)' % UiStrings().AllFiles
-        filenames = QtGui.QFileDialog.getOpenFileNames(self,
+        filenames = FileDialog.getOpenFileNames(self,
             translate('SongsPlugin.EditSongForm', 'Open File(s)'),
             QtCore.QString(), filters)
         for filename in filenames:
@@ -938,4 +1016,5 @@ class EditSongForm(QtGui.QDialog, Ui_EditSongDialog):
         except:
             log.exception(u'Problem processing song Lyrics \n%s',
                 sxml.dump_xml())
+            raise
 
