@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -32,14 +32,14 @@ from PyQt4 import QtCore, QtGui
 from openlp.core.lib import translate, build_icon
 from openlp.core.lib.ui import create_button_box
 
+
 class Ui_MediaFilesDialog(object):
     def setupUi(self, mediaFilesDialog):
         mediaFilesDialog.setObjectName(u'mediaFilesDialog')
         mediaFilesDialog.setWindowModality(QtCore.Qt.ApplicationModal)
         mediaFilesDialog.resize(400, 300)
         mediaFilesDialog.setModal(True)
-        mediaFilesDialog.setWindowIcon(
-            build_icon(u':/icon/openlp-logo-16x16.png'))
+        mediaFilesDialog.setWindowIcon(build_icon(u':/icon/openlp-logo.svg'))
         self.filesVerticalLayout = QtGui.QVBoxLayout(mediaFilesDialog)
         self.filesVerticalLayout.setSpacing(8)
         self.filesVerticalLayout.setMargin(8)
