@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -33,11 +33,14 @@ from openlp.core.lib import build_icon
 from openlp.core.lib.ui import UiStrings, create_button_box
 from openlp.plugins.songs.lib.ui import SongStrings
 
+
 class Ui_SongMaintenanceDialog(object):
     def setupUi(self, songMaintenanceDialog):
         songMaintenanceDialog.setObjectName(u'songMaintenanceDialog')
         songMaintenanceDialog.setWindowModality(QtCore.Qt.ApplicationModal)
         songMaintenanceDialog.resize(10, 350)
+        songMaintenanceDialog.setWindowIcon(
+            build_icon(u':/icon/openlp-logo.svg'))
         self.dialogLayout = QtGui.QGridLayout(songMaintenanceDialog)
         self.dialogLayout.setObjectName(u'dialogLayout')
         self.typeListWidget = QtGui.QListWidget(songMaintenanceDialog)
