@@ -4,8 +4,8 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2013 Raoul Snyman                                        #
-# Portions copyright (c) 2008-2013 Tim Bentley, Gerald Britton, Jonathan      #
+# Copyright (c) 2008-2014 Raoul Snyman                                        #
+# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
 # Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
 # Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
 # Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
@@ -32,10 +32,13 @@ from PyQt4 import QtCore, QtGui
 from openlp.core.lib import build_icon, translate
 from openlp.core.lib.ui import create_button_box
 
+
 class Ui_SongUsageDetailDialog(object):
     def setupUi(self, songUsageDetailDialog):
         songUsageDetailDialog.setObjectName(u'songUsageDetailDialog')
         songUsageDetailDialog.resize(609, 413)
+        songUsageDetailDialog.setWindowIcon(
+            build_icon(u':/icon/openlp-logo.svg'))
         self.verticalLayout = QtGui.QVBoxLayout(songUsageDetailDialog)
         self.verticalLayout.setSpacing(8)
         self.verticalLayout.setContentsMargins(8, 8, 8, 8)
